==> fetch.php?media=uls%3Auls_update-1.9.5.tgz: update/von_1.9.4/sql/getzwertvbextfilter.sql <==
set @@character_set_client = 'utf8';

delimiter //

DROP FUNCTION IF EXISTS getzwertvbextfilter//
create function getzwertvbextfilter(wid integer, von datetime, bis datetime,
  mode varchar(12), zvon time, zbis time, wtf varchar(20),
  vg1 varchar(3), wf1 varchar(250),
  m2 varchar(3), vg2 varchar(3), wf2 varchar(250),
  m3 varchar(3), vg3 varchar(3), wf3 varchar(250),
  m4 varchar(3), vg4 varchar(3), wf4 varchar(250))
                  returns varchar(30)
deterministic
sql security invoker
begin
  declare r, l varchar(20);
  declare ld datetime;
  declare va, ba, vo, bo time;
  declare f integer;

  if TIME(zvon) < TIME(zbis)
   then
    set va = TIME(zvon);
    set ba = TIME(zbis);
    set vo = '24:00:00';
    set bo = '-00:00:01';
  else
    set va = '24:00:00';
    set ba = '-00:00:01';
    set vo = TIME(zvon);
    set bo = TIME(zbis);
  end if;
  case mode
    when 'min' then
      select min(wert+0) from zwerte
      where werteindizesID = wid and von <= datum and datum <= bis
        and ((va <= TIME(datum) and TIME(datum) <= ba)
             or vo <= TIME(datum) or TIME(datum) <= bo)
        and (wtf = '' or find_in_set(DAYOFWEEK(datum), wtf))
        and extfilter(wert, vg1, wf1, m2, vg2, wf2, m3, vg3, wf3, m4, vg4, wf4)
      into r;
    when 'max' then
      select max(wert+0) from zwerte
      where werteindizesID = wid and von <= datum and datum <= bis
        and ((va <= TIME(datum) and TIME(datum) <= ba)
             or vo <= TIME(datum) or TIME(datum) <= bo)
        and (wtf = '' or find_in_set(DAYOFWEEK(datum), wtf))
        and extfilter(wert, vg1, wf1, m2, vg2, wf2, m3, vg3, wf3, m4, vg4, wf4)
      into r;
    when 'avg' then
      select avg(wert+0), max(length(0+replace(wert, '.',''))) from zwerte
      where werteindizesID = wid and von <= datum and datum <= bis
        and ((va <= TIME(datum) and TIME(datum) <= ba)
             or vo <= TIME(datum) or TIME(datum) <= bo)
        and (wtf = '' or find_in_set(DAYOFWEEK(datum), wtf))
        and extfilter(wert, vg1, wf1, m2, vg2, wf2, m3, vg3, wf3, m4, vg4, wf4)
      into r, f;
      return round(r, f + 2 - locate('.', r));
    when 'last/avg' then
      select wert, datum from zwerte
        where werteindizesID = wid and von <= datum and datum <= bis
          and ((va <= TIME(datum) and TIME(datum) <= ba)
               or vo <= TIME(datum) or TIME(datum) <= bo)
          and (wtf = '' or find_in_set(DAYOFWEEK(datum), wtf))
          and extfilter(wert, vg1, wf1, m2, vg2, wf2, m3, vg3, wf3, m4, vg4, wf4)
        order by datum desc limit 1 into l, ld;
      select avg(wert+0), max(length(0+replace(wert, '.',''))) from zwerte
      where werteindizesID = wid and von <= datum and datum < ld
        and ((va <= TIME(datum) and TIME(datum) <= ba)
             or vo <= TIME(datum) or TIME(datum) <= bo)
        and (wtf = '' or find_in_set(DAYOFWEEK(datum), wtf))
        and extfilter(wert, vg1, wf1, m2, vg2, wf2, m3, vg3, wf3, m4, vg4, wf4)
      into r, f;
      if r != 0 then
        return round(l/r, f + 2 - locate('.', l/r));
      else
        return NULL;
      end if;
    when 'last/avg-1' then
      select wert, datum from zwerte
        where werteindizesID = wid and von <= datum and datum <= bis
          and ((va <= TIME(datum) and TIME(datum) <= ba)
               or vo <= TIME(datum) or TIME(datum) <= bo)
          and (wtf = '' or find_in_set(DAYOFWEEK(datum), wtf))
          and extfilter(wert, vg1, wf1, m2, vg2, wf2, m3, vg3, wf3, m4, vg4, wf4)
        order by datum desc limit 1 into l, ld;
      select avg(wert+0), max(length(0+replace(wert, '.',''))) from zwerte
      where werteindizesID = wid and von <= datum and datum < ld
        and ((va <= TIME(datum) and TIME(datum) <= ba)
             or vo <= TIME(datum) or TIME(datum) <= bo)
        and (wtf = '' or find_in_set(DAYOFWEEK(datum), wtf))
        and extfilter(wert, vg1, wf1, m2, vg2, wf2, m3, vg3, wf3, m4, vg4, wf4)
      into r, f;
      if r != 0 then
        return round(l/r-1, f + 2 - locate('.', l/r-1));
      else
        return NULL;
      end if;
    when 'dev' then
      select stddev_samp(wert+0) from zwerte
      where werteindizesID = wid and von <= datum and datum <= bis
        and ((va <= TIME(datum) and TIME(datum) <= ba)
             or vo <= TIME(datum) or TIME(datum) <= bo)
        and (wtf = '' or find_in_set(DAYOFWEEK(datum), wtf))
        and extfilter(wert, vg1, wf1, m2, vg2, wf2, m3, vg3, wf3, m4, vg4, wf4)
      into r;
    when 'sum' then
      select sum(wert+0), max(locate('.', reverse(wert))) from zwerte
      where werteindizesID = wid and von <= datum and datum <= bis
        and ((va <= TIME(datum) and TIME(datum) <= ba)
             or vo <= TIME(datum) or TIME(datum) <= bo)
        and (wtf = '' or find_in_set(DAYOFWEEK(datum), wtf))
        and extfilter(wert, vg1, wf1, m2, vg2, wf2, m3, vg3, wf3, m4, vg4, wf4)
      into r, f;
      if f < 0 then
        set f = 0;
      end if;
      return round(r, f);
    when 'max-min' then
      select max(wert+0)-min(wert+0) from zwerte
      where werteindizesID = wid and von <= datum and datum <= bis
        and ((va <= TIME(datum) and TIME(datum) <= ba)
             or vo <= TIME(datum) or TIME(datum) <= bo)
        and (wtf = '' or find_in_set(DAYOFWEEK(datum), wtf))
        and extfilter(wert, vg1, wf1, m2, vg2, wf2, m3, vg3, wf3, m4, vg4, wf4)
      into r;
    when 'last-first' then
      return (select wert from zwerte
              where werteindizesID = wid and von <= datum and datum <= bis
                and ((va <= TIME(datum) and TIME(datum) <= ba)
                     or vo <= TIME(datum) or TIME(datum) <= bo)
                and (wtf = '' or find_in_set(DAYOFWEEK(datum), wtf))
                and extfilter(wert, vg1, wf1, m2, vg2, wf2, m3, vg3, wf3, m4, vg4, wf4)
              order by datum desc limit 1)
           - (select wert from zwerte
              where werteindizesID = wid and von <= datum and datum <= bis
                and ((va <= TIME(datum) and TIME(datum) <= ba)
                     or vo <= TIME(datum) or TIME(datum) <= bo)
                and (wtf = '' or find_in_set(DAYOFWEEK(datum), wtf))
                and extfilter(wert, vg1, wf1, m2, vg2, wf2, m3, vg3, wf3, m4, vg4, wf4)
              order by datum limit 1);
    when 'last-first+' then
      set r = (select wert from zwerte
              where werteindizesID = wid and von <= datum and datum <= bis
                and ((va <= TIME(datum) and TIME(datum) <= ba)
                     or vo <= TIME(datum) or TIME(datum) <= bo)
                and (wtf = '' or find_in_set(DAYOFWEEK(datum), wtf))
                and extfilter(wert, vg1, wf1, m2, vg2, wf2, m3, vg3, wf3, m4, vg4, wf4)
              order by datum desc limit 1)
           - (select wert from zwerte
              where werteindizesID = wid and von <= datum and datum <= bis
                and ((va <= TIME(datum) and TIME(datum) <= ba)
                     or vo <= TIME(datum) or TIME(datum) <= bo)
                and (wtf = '' or find_in_set(DAYOFWEEK(datum), wtf))
                and extfilter(wert, vg1, wf1, m2, vg2, wf2, m3, vg3, wf3, m4, vg4, wf4)
              order by datum limit 1);
      if r < 0 then
        return NULL;
      end if;
    when 'last-first-' then
      set r = (select wert from zwerte
              where werteindizesID = wid and von <= datum and datum <= bis
                and ((va <= TIME(datum) and TIME(datum) <= ba)
                     or vo <= TIME(datum) or TIME(datum) <= bo)
                and (wtf = '' or find_in_set(DAYOFWEEK(datum), wtf))
                and extfilter(wert, vg1, wf1, m2, vg2, wf2, m3, vg3, wf3, m4, vg4, wf4)
              order by datum desc limit 1)
           - (select wert from zwerte
              where werteindizesID = wid and von <= datum and datum <= bis
                and ((va <= TIME(datum) and TIME(datum) <= ba)
                     or vo <= TIME(datum) or TIME(datum) <= bo)
                and (wtf = '' or find_in_set(DAYOFWEEK(datum), wtf))
                and extfilter(wert, vg1, wf1, m2, vg2, wf2, m3, vg3, wf3, m4, vg4, wf4)
              order by datum limit 1);
      if r > 0 then
        return NULL;
      end if;
    when 'first' then
      select wert from zwerte
      where werteindizesID = wid and von <= datum and datum <= bis
        and ((va <= TIME(datum) and TIME(datum) <= ba)
              or vo <= TIME(datum) or TIME(datum) <= bo)
        and (wtf = '' or find_in_set(DAYOFWEEK(datum), wtf))
             and extfilter(wert, vg1, wf1, m2, vg2, wf2, m3, vg3, wf3, m4, vg4, wf4)
        order by datum limit 1
      into r;
    when 'differ' then
      return BINARY (select wert from zwerte
              where werteindizesID = wid and von <= datum and datum <= bis
                and ((va <= TIME(datum) and TIME(datum) <= ba)
                     or vo <= TIME(datum) or TIME(datum) <= bo)
                and (wtf = '' or find_in_set(DAYOFWEEK(datum), wtf))
                and extfilter(wert, vg1, wf1, m2, vg2, wf2, m3, vg3, wf3, m4, vg4, wf4)
              order by datum desc limit 1)
          != BINARY (select wert from zwerte
              where werteindizesID = wid and von <= datum and datum <= bis
                and ((va <= TIME(datum) and TIME(datum) <= ba)
                     or vo <= TIME(datum) or TIME(datum) <= bo)
                and (wtf = '' or find_in_set(DAYOFWEEK(datum), wtf))
                and extfilter(wert, vg1, wf1, m2, vg2, wf2, m3, vg3, wf3, m4, vg4, wf4)
              order by datum limit 1);
    when 'count' then
      select count(*) from zwerte
      where werteindizesID = wid and von <= datum and datum <= bis
        and ((va <= TIME(datum) and TIME(datum) <= ba)
             or vo <= TIME(datum) or TIME(datum) <= bo)
        and (wtf = '' or find_in_set(DAYOFWEEK(datum), wtf))
        and extfilter(wert, vg1, wf1, m2, vg2, wf2, m3, vg3, wf3, m4, vg4, wf4)
      into r;
    when 'grad' then
      return gradientzvbextfilter(wid, von, bis, zvon, zbis, wtf,
              vg1, wf1, m2, vg2, wf2, m3, vg3, wf3, m4, vg4, wf4);
    when 'accel' then
      return accelz(wid, von, bis, zvon, zbis, wtf,
              vg1, wf1, m2, vg2, wf2, m3, vg3, wf3, m4, vg4, wf4);
    when 'last' then
      select wert from zwerte
      where werteindizesID = wid and von <= datum and datum <= bis
        and ((va <= TIME(datum) and TIME(datum) <= ba)
             or vo <= TIME(datum) or TIME(datum) <= bo)
        and (wtf = '' or find_in_set(DAYOFWEEK(datum), wtf))
        and extfilter(wert, vg1, wf1, m2, vg2, wf2, m3, vg3, wf3, m4, vg4, wf4)
      order by datum desc limit 1
      into r;
    else
      return NULL;
  end case;
  return r;
end//

GRANT EXECUTE on FUNCTION getzwertvbextfilter to logginglesen@'localhost'//

==> fetch.php?media=uls%3Auls_update-1.9.6.tgz: update/von_1.9.5/sql/getzwertvbextfilter.sql <==
-- getzwertvbextfilter.sql
--
-- function getzwertvbextfilter(wid, von, bis, mode, zvon, zbis, wtf, vg1, wf1, m2, vg2, wf2, m3, vg3, wf3, m4, vg4, wf4) returns varchar
-- wid: werteindizesID
-- von: datetime from
-- bis: datetime to
-- mode: aggregation function
-- zvon: time from
-- zbis: time to
-- wtf: set of weekdays
-- vg1: comparevalue 1
-- wf1: comparefunction 1
-- m2: OR|AND
-- vg2: comparevalue 2
-- wf2: comparefunction 2
-- m3: OR|AND
-- vg3: comparevalue 3
-- wf3: comparefunction 3
-- m4: OR|AND
-- vg4: comparevalue 4
-- wf4: comparefunction 4
-- return: aggragated value with extended filter (table zwerte)

set @@character_set_client = 'utf8';

delimiter //

DROP FUNCTION IF EXISTS getzwertvbextfilter//
create function getzwertvbextfilter(wid integer, von datetime, bis datetime,
  mode varchar(12), zvon time, zbis time, wtf varchar(20),
  vg1 varchar(3), wf1 varchar(250),
  m2 varchar(3), vg2 varchar(3), wf2 varchar(250),
  m3 varchar(3), vg3 varchar(3), wf3 varchar(250),
  m4 varchar(3), vg4 varchar(3), wf4 varchar(250))
                  returns varchar(30)
deterministic
sql security invoker
begin
  declare v double;
  declare r, l varchar(20);
  declare ld datetime;
  declare va, ba, vo, bo time;
  declare f integer;

  if TIME(zvon) < TIME(zbis)
   then
    set va = TIME(zvon);
    set ba = TIME(zbis);
    set vo = '24:00:00';
    set bo = '-00:00:01';
  else
    set va = '24:00:00';
    set ba = '-00:00:01';
    set vo = TIME(zvon);
    set bo = TIME(zbis);
  end if;
  case mode
    when 'min' then
      select min(wert+0) into r from zwerte
        where werteindizesID = wid and von <= datum and datum <= bis
          and ((va <= TIME(datum) and TIME(datum) <= ba)
               or vo <= TIME(datum) or TIME(datum) <= bo)
          and (wtf = '' or find_in_set(DAYOFWEEK(datum), wtf))
          and extfilter(wert, vg1, wf1, m2, vg2, wf2, m3, vg3, wf3, m4, vg4, wf4);
    when 'max' then
      select max(wert+0) into r from zwerte
        where werteindizesID = wid and von <= datum and datum <= bis
          and ((va <= TIME(datum) and TIME(datum) <= ba)
               or vo <= TIME(datum) or TIME(datum) <= bo)
          and (wtf = '' or find_in_set(DAYOFWEEK(datum), wtf))
          and extfilter(wert, vg1, wf1, m2, vg2, wf2, m3, vg3, wf3, m4, vg4, wf4);
    when 'avg' then
      select avg(wert+0), max(length(0+replace(wert, '.',''))) into v, f from zwerte
        where werteindizesID = wid and von <= datum and datum <= bis
          and ((va <= TIME(datum) and TIME(datum) <= ba)
               or vo <= TIME(datum) or TIME(datum) <= bo)
          and (wtf = '' or find_in_set(DAYOFWEEK(datum), wtf))
          and extfilter(wert, vg1, wf1, m2, vg2, wf2, m3, vg3, wf3, m4, vg4, wf4);
      return round(v, f + 2 - locate('.', v));
    when 'last/avg' then
      select wert, datum into l, ld from zwerte
        where werteindizesID = wid and von <= datum and datum <= bis
          and ((va <= TIME(datum) and TIME(datum) <= ba)
               or vo <= TIME(datum) or TIME(datum) <= bo)
          and (wtf = '' or find_in_set(DAYOFWEEK(datum), wtf))
          and extfilter(wert, vg1, wf1, m2, vg2, wf2, m3, vg3, wf3, m4, vg4, wf4)
        order by datum desc limit 1;
      select avg(wert+0), max(length(0+replace(wert, '.',''))) into v, f from zwerte
        where werteindizesID = wid and von <= datum and datum < ld
          and ((va <= TIME(datum) and TIME(datum) <= ba)
               or vo <= TIME(datum) or TIME(datum) <= bo)
          and (wtf = '' or find_in_set(DAYOFWEEK(datum), wtf))
          and extfilter(wert, vg1, wf1, m2, vg2, wf2, m3, vg3, wf3, m4, vg4, wf4);
      if v != 0 then
        return round(l/v, f + 2 - locate('.', l/v));
      else
        return NULL;
      end if;
    when 'last/avg-1' then
      select wert, datum into l, ld from zwerte
        where werteindizesID = wid and von <= datum and datum <= bis
          and ((va <= TIME(datum) and TIME(datum) <= ba)
               or vo <= TIME(datum) or TIME(datum) <= bo)
          and (wtf = '' or find_in_set(DAYOFWEEK(datum), wtf))
          and extfilter(wert, vg1, wf1, m2, vg2, wf2, m3, vg3, wf3, m4, vg4, wf4)
        order by datum desc limit 1;
      select avg(wert+0), max(length(0+replace(wert, '.',''))) into v, f from zwerte
        where werteindizesID = wid and von <= datum and datum < ld
          and ((va <= TIME(datum) and TIME(datum) <= ba)
               or vo <= TIME(datum) or TIME(datum) <= bo)
          and (wtf = '' or find_in_set(DAYOFWEEK(datum), wtf))
          and extfilter(wert, vg1, wf1, m2, vg2, wf2, m3, vg3, wf3, m4, vg4, wf4);
      if v != 0 then
        return round(l/v-1, f + 2 - locate('.', l/v-1));
      else
        return NULL;
      end if;
    when 'dev' then
      select stddev_samp(wert+0), max(length(0+replace(wert, '.',''))) + 2 - locate('.', avg(wert+0)) into v, f from zwerte
        where werteindizesID = wid and von <= datum and datum <= bis
          and ((va <= TIME(datum) and TIME(datum) <= ba)
               or vo <= TIME(datum) or TIME(datum) <= bo)
          and (wtf = '' or find_in_set(DAYOFWEEK(datum), wtf))
          and extfilter(wert, vg1, wf1, m2, vg2, wf2, m3, vg3, wf3, m4, vg4, wf4);
      return round(v, f);
    when 'sum' then
      select sum(wert+0), max(locate('.', reverse(wert))) into r, f from zwerte
        where werteindizesID = wid and von <= datum and datum <= bis
          and ((va <= TIME(datum) and TIME(datum) <= ba)
               or vo <= TIME(datum) or TIME(datum) <= bo)
          and (wtf = '' or find_in_set(DAYOFWEEK(datum), wtf))
          and extfilter(wert, vg1, wf1, m2, vg2, wf2, m3, vg3, wf3, m4, vg4, wf4);
      if f < 0 then
        set f = 0;
      end if;
      return round(r, f);
    when 'max-min' then
      select max(wert+0)-min(wert+0) into r from zwerte
        where werteindizesID = wid and von <= datum and datum <= bis
          and ((va <= TIME(datum) and TIME(datum) <= ba)
               or vo <= TIME(datum) or TIME(datum) <= bo)
          and (wtf = '' or find_in_set(DAYOFWEEK(datum), wtf))
          and extfilter(wert, vg1, wf1, m2, vg2, wf2, m3, vg3, wf3, m4, vg4, wf4);
    when 'last-first' then
      return (select wert from zwerte
              where werteindizesID = wid and von <= datum and datum <= bis
                and ((va <= TIME(datum) and TIME(datum) <= ba)
                     or vo <= TIME(datum) or TIME(datum) <= bo)
                and (wtf = '' or find_in_set(DAYOFWEEK(datum), wtf))
                and extfilter(wert, vg1, wf1, m2, vg2, wf2, m3, vg3, wf3, m4, vg4, wf4)
              order by datum desc limit 1)
           - (select wert from zwerte
              where werteindizesID = wid and von <= datum and datum <= bis
                and ((va <= TIME(datum) and TIME(datum) <= ba)
                     or vo <= TIME(datum) or TIME(datum) <= bo)
                and (wtf = '' or find_in_set(DAYOFWEEK(datum), wtf))
                and extfilter(wert, vg1, wf1, m2, vg2, wf2, m3, vg3, wf3, m4, vg4, wf4)
              order by datum limit 1);
    when 'last-first+' then
      set r = (select wert from zwerte
              where werteindizesID = wid and von <= datum and datum <= bis
                and ((va <= TIME(datum) and TIME(datum) <= ba)
                     or vo <= TIME(datum) or TIME(datum) <= bo)
                and (wtf = '' or find_in_set(DAYOFWEEK(datum), wtf))
                and extfilter(wert, vg1, wf1, m2, vg2, wf2, m3, vg3, wf3, m4, vg4, wf4)
              order by datum desc limit 1)
           - (select wert from zwerte
              where werteindizesID = wid and von <= datum and datum <= bis
                and ((va <= TIME(datum) and TIME(datum) <= ba)
                     or vo <= TIME(datum) or TIME(datum) <= bo)
                and (wtf = '' or find_in_set(DAYOFWEEK(datum), wtf))
                and extfilter(wert, vg1, wf1, m2, vg2, wf2, m3, vg3, wf3, m4, vg4, wf4)
              order by datum limit 1);
      if r < 0 then
        return NULL;
      end if;
    when 'last-first-' then
      set r = (select wert from zwerte
              where werteindizesID = wid and von <= datum and datum <= bis
                and ((va <= TIME(datum) and TIME(datum) <= ba)
                     or vo <= TIME(datum) or TIME(datum) <= bo)
                and (wtf = '' or find_in_set(DAYOFWEEK(datum), wtf))
                and extfilter(wert, vg1, wf1, m2, vg2, wf2, m3, vg3, wf3, m4, vg4, wf4)
              order by datum desc limit 1)
           - (select wert from zwerte
              where werteindizesID = wid and von <= datum and datum <= bis
                and ((va <= TIME(datum) and TIME(datum) <= ba)
                     or vo <= TIME(datum) or TIME(datum) <= bo)
                and (wtf = '' or find_in_set(DAYOFWEEK(datum), wtf))
                and extfilter(wert, vg1, wf1, m2, vg2, wf2, m3, vg3, wf3, m4, vg4, wf4)
              order by datum limit 1);
      if r > 0 then
        return NULL;
      end if;
    when 'first' then
      select wert into r from zwerte
        where werteindizesID = wid and von <= datum and datum <= bis
          and ((va <= TIME(datum) and TIME(datum) <= ba)
                or vo <= TIME(datum) or TIME(datum) <= bo)
          and (wtf = '' or find_in_set(DAYOFWEEK(datum), wtf))
               and extfilter(wert, vg1, wf1, m2, vg2, wf2, m3, vg3, wf3, m4, vg4, wf4)
          order by datum limit 1;
    when 'differ' then
      return BINARY (select wert from zwerte
              where werteindizesID = wid and von <= datum and datum <= bis
                and ((va <= TIME(datum) and TIME(datum) <= ba)
                     or vo <= TIME(datum) or TIME(datum) <= bo)
                and (wtf = '' or find_in_set(DAYOFWEEK(datum), wtf))
                and extfilter(wert, vg1, wf1, m2, vg2, wf2, m3, vg3, wf3, m4, vg4, wf4)
              order by datum desc limit 1)
          != BINARY (select wert from zwerte
              where werteindizesID = wid and von <= datum and datum <= bis
                and ((va <= TIME(datum) and TIME(datum) <= ba)
                     or vo <= TIME(datum) or TIME(datum) <= bo)
                and (wtf = '' or find_in_set(DAYOFWEEK(datum), wtf))
                and extfilter(wert, vg1, wf1, m2, vg2, wf2, m3, vg3, wf3, m4, vg4, wf4)
              order by datum limit 1);
    when 'count' then
      select count(*) into r from zwerte
        where werteindizesID = wid and von <= datum and datum <= bis
          and ((va <= TIME(datum) and TIME(datum) <= ba)
               or vo <= TIME(datum) or TIME(datum) <= bo)
          and (wtf = '' or find_in_set(DAYOFWEEK(datum), wtf))
          and extfilter(wert, vg1, wf1, m2, vg2, wf2, m3, vg3, wf3, m4, vg4, wf4);
    when 'grad' then
      return gradientzvbextfilter(wid, von, bis, zvon, zbis, wtf,
              vg1, wf1, m2, vg2, wf2, m3, vg3, wf3, m4, vg4, wf4);
    when 'accel' then
      return accelz(wid, von, bis, zvon, zbis, wtf,
              vg1, wf1, m2, vg2, wf2, m3, vg3, wf3, m4, vg4, wf4);
    when 'last' then
      select wert into r from zwerte
        where werteindizesID = wid and von <= datum and datum <= bis
          and ((va <= TIME(datum) and TIME(datum) <= ba)
               or vo <= TIME(datum) or TIME(datum) <= bo)
          and (wtf = '' or find_in_set(DAYOFWEEK(datum), wtf))
          and extfilter(wert, vg1, wf1, m2, vg2, wf2, m3, vg3, wf3, m4, vg4, wf4)
        order by datum desc limit 1;
    else
      return NULL;
  end case;
  return r;
end//

GRANT EXECUTE on FUNCTION getzwertvbextfilter to logginglesen@'localhost'//
